<?php
/**
 * Set publisher layout according to options
 *
 * @package Publisher
 */

defined( 'WPINC' ) || exit;

/**
 * Layout manager.
 */
class Publisher_Layout extends Publisher_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'publisher_before_wrapper', 'add_header' );
		$this->add_action( 'publisher_single_post_full_header', 'single_post_full_header' );
		$this->add_action( 'publisher_single_post_header_thumb', 'single_post_header_thumb' );
		$this->add_action( 'publisher_blog_featured_area_section', 'blog_featured_area_section' );
		$this->add_action( 'publisher_breadcrumb_lists', 'breadcrumb_lists' );
		$this->add_action( 'publisher_before_footer', 'full_related_posts' );
	}

	/**
	 * Add header
	 */
	public function add_header() {
		$hash   = [
			'header-default' => 'default',
			'header-layout2' => 'layout2',
		];
		$layout = publisher_get_settings( 'header_styles' );
		get_template_part( 'template-parts/header/header', isset( $hash[ $layout ] ) ? $hash[ $layout ] : $layout );
	}

	/**
	 * Single post header thumbnail
	 */
	public function single_post_header_thumb() {
		$img_size         = publisher_get_settings( 'featured_image_size' );
		$header_animation = publisher_get_post_header_effect();
		if ( 'default' === $img_size ) :
			if ( ! has_post_thumbnail() ) {
				return;
			}
			publisher_single_featured_image_effect();
			if ( ! $header_animation && publisher_get_settings( 'show_single_featured' ) ) {
				the_post_thumbnail( 'publisher-layout-2', [ 'class' => 'single-featured-image' ] );
			}
			?>
			<header>
				<?php blog_post_metainfo( 'single', 'top', false ); ?>
				<h1 class="single-title"><?php the_title(); ?></h1>
				<?php blog_post_metainfo( 'single', false, 'bottom' ); ?>
			</header>
			<?php
		endif;
	}

	/**
	 * Single post header if fullwidth layout
	 */
	public function single_post_full_header() {
		$img_size         = publisher_get_settings( 'featured_image_size' );
		$alignment        = publisher_get_settings( 'featured_text_alignment' );
		$header_animation = publisher_get_post_header_effect();
		if ( 'full' === $img_size ) :
			if ( have_posts() ) :
				while ( have_posts() ) :
					the_post();
					global $post;
					$featured_image = [];
					$header_style   = '';
					if ( publisher_get_settings( 'show_single_featured' ) && has_post_thumbnail() ) {
						$featured_image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );
						$header_style   = 'style = "background-image: url(' . esc_url( $featured_image[0] ) . ');"';
					}
					if ( 'parallax' === $header_animation && has_post_thumbnail() ) {
						echo '<header id="parallax" class="single-full-header clearfix" style="background-image: url(' . get_the_post_thumbnail_url( get_the_ID(), 'full' ) . ');">';
					} elseif ( 'zoomout' === $header_animation && has_post_thumbnail() ) {
						echo '<header id="zoom-out-effect"><div id="zoom-out-bg" class="single-full-header clearfix" style="background-image: url(' . get_the_post_thumbnail_url( get_the_ID(), 'full' ) . ');">';
					} else {
						?>
						<header class="single-full-header clearfix" <?php echo $header_style; ?>>
						<?php
					}
					if ( publisher_get_settings( 'show_prev_next' ) ) {
						?>
						<div class="prev-next">
							<?php
							previous_post_link( '<div class="prev">%link</div>', '<i class="fa fa-angle-left"></i>', true );
							next_post_link( '<div class="next">%link</div>', '<i class="fa fa-angle-right"></i>', true );
							?>
						</div>
						<?php
					}
					?>
					<div class="single-full-header-content single-post-<?php echo $alignment; ?> clearfix">
						<div class="container">
							<div class="full-header-wrapper clearfix">
								<?php blog_post_metainfo( 'single', 'top', false ); ?>
								<h1 class="single-title"><?php the_title(); ?></h1>
								<?php blog_post_metainfo( 'single', false, 'bottom' ); ?>
							</div>
						</div>
					</div>
					<?php
					if ( 'zoomout' === $header_animation && has_post_thumbnail() ) :
						echo '</div>';
					endif;
					?>
				</header>
					<?php
				endwhile;
			endif; /* end loop */
		endif;
	}

	/**
	 * Featured Area
	 */
	public function blog_featured_area_section() {
		if ( ! is_paged() && publisher_get_settings( 'show_featured_area' ) ) :
			featured_area_section();
		endif;
	}

	/**
	 * Breadcrumb
	 */
	public function breadcrumb_lists() {
		publisher_breadcrumbs();
	}

	/**
	 * Single post related posts
	 */
	public function full_related_posts( $position = 'full' ) {
		if ( 'full' === publisher_get_settings( 'related_posts_position' ) ) {
			publisher_related_posts();
		}
	}

}

// Init.
new Publisher_Layout;
