<?php
/**
 * Archive Pages
 *
 * @package Publisher
 */

$menus['blog-archive'] = [
	'icon'  => 'fa-archive',
	'title' => esc_html__( 'Archives', 'publisher' ),
	'desc'  => esc_html__( 'From here, you can control the elements of the archive pages.', 'publisher' ),
];

// Dependency check that excerpt is enable.
$archive_excerpt_dependency = [
	'relation' => 'and',
	[
		'field'      => 'archive_post_excerpt',
		'value'      => '1',
		'comparison' => '==',
	],
];

$sections['blog-archive'] = [
	[
		'id'       => 'mts_archive_headline_meta_info',
		'type'     => 'multi_checkbox',
		'title'    => esc_html__( 'Post Meta Info', 'publisher' ),
		'sub_desc' => esc_html__( 'Show or hide post meta info.', 'publisher' ),
		'options'  => [
			'category' => esc_html__( 'Category', 'publisher' ),
			'comment'  => esc_html__( 'Comments', 'publisher' ),
			'auth-img' => esc_html__( 'Author Image', 'publisher' ),
			'author'   => esc_html__( 'Author Name', 'publisher' ),
			'time'     => esc_html__( 'Time/Date', 'publisher' ),
			'likes'    => esc_html__( 'Likes', 'publisher' ),
		],
		'std'      => [
			'category',
			'auth-img',
			'author',
			'time',
			'likes',
		],
	],
	[
		'id'       => 'mts_archive_category_type',
		'type'     => 'button_set',
		'title'    => esc_html__( 'Categories', 'publisher' ),
		'options'  => [
			'0' => esc_html__( 'First Category', 'publisher' ),
			'1' => esc_html__( 'ALL Categories', 'publisher' ),
		],
		'sub_desc' => esc_html__( 'Show only first category or all the categories of post from here.', 'publisher' ),
		'std'      => '0',
	],
	[
		'id'    => 'archive_post_title_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Archive Post Font', 'publisher' ),
	],
	[
		'id'    => 'archive_post_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Post Title Font', 'publisher' ),
		'std'   => [
			'preview-text'  => 'Post Title Font',
			'preview-color' => 'light',
			'font-family'   => 'Lexend Deca',
			'font-weight'   => '700',
			'font-size'     => '16px',
			'line-height'   => '1.5',
			'margin-top'    => '5px',
			'margin-bottom' => '5px',
			'color'         => '#2d2b2b',
			'css-selectors' => '.latestPost .title a, .archive .latestPost .title a, .search .latestPost .title a, .archive [class^="more-page"] .latestPost .title a, .search [class^="more-page"] .latestPost .title a',
		],
	],
	[
		'id'       => 'archive_post_excerpt',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Post Excerpts', 'publisher' ),
		'sub_desc' => esc_html__( 'Use this button to show or hide small post excerpt.', 'publisher' ),
		'std'      => '1',
	],
	[
		'id'         => 'archive_excerpt',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Excerpt Length', 'publisher' ),
		'sub_desc'   => esc_html__( 'Max lenght is 55 Words.', 'publisher' ),
		'args'       => [ 'type' => 'number' ],
		'std'        => '15',
		'dependency' => $archive_excerpt_dependency,
	],
	[
		'id'         => 'archive_post_excerpt_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Post Excerpt Font', 'publisher' ),
		'std'        => [
			'preview-text'   => 'Post Excerpt Font',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '12px',
			'line-height'    => publisher_line_height( 12, 20 ),
			'color'          => '#848fa1',
			'margin-bottom'  => publisher_px2rem( 15 ),
			'letter-spacing' => publisher_letter_spacing( 12, 36 ),
			'css-selectors'  => '.archive .latestPost .front-view-content, .search .latestPost .front-view-content, .archive [class^="more-page"] .latestPost .front-view-content, .search [class^="more-page"] .latestPost .front-view-content',
		],
		'dependency' => $archive_excerpt_dependency,
	],
	[
		'id'    => 'archive_meta_cats_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Category Typography', 'publisher' ),
		'std'   => [
			'preview-text'   => 'Category Font',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '12px',
			'color'          => '#bf2600',
			'letter-spacing' => publisher_letter_spacing( 12, 167 ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.archive .latestPost .thecategory a, .search .latestPost .thecategory a',
		],
	],
	[
		'id'    => 'archive_meta_author_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Author Meta Info Typography', 'publisher' ),
		'std'   => [
			'preview-text'   => 'Author Meta Info Font',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '14px',
			'color'          => '#495c8e',
			'line-height'    => '1.2',
			'letter-spacing' => publisher_letter_spacing( 14, 36 ),
			'css-selectors'  => '.archive .latestPost .theauthor, .archive .latestPost .thecomment, .search .latestPost .theauthor, .search .latestPost .thecomment, .archive .latestPost .sl-count, .search .latestPost .sl-count',
		],
	],
	[
		'id'    => 'archive_meta_date_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Date Typography', 'publisher' ),
		'std'   => [
			'preview-text'   => 'Date Font',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '11px',
			'color'          => '#848fa1',
			'line-height'    => '1.2',
			'letter-spacing' => publisher_letter_spacing( 11, 45 ),
			'css-selectors'  => '.archive .latestPost .thetime, .search .latestPost .thetime',
		],
	],
];
