<?php
/**
 * Archive Pages
 *
 * @package Publisher
 */

$menus['blog-featured-area'] = [
	'icon'  => 'fa-sliders',
	'title' => esc_html__( 'Featured Area', 'publisher' ),
	'desc'  => esc_html__( 'From here, you can control the elements of the Featured Area.', 'publisher' ),
];

$featured_dependency = [
	'field'      => 'show_featured_area',
	'value'      => '1',
	'comparison' => '==',
];


// Dependency check that excerpt is enable.
$featured_excerpt_dependency = [
	'field'      => 'featured_post_excerpt',
	'value'      => '1',
	'comparison' => '==',
];

$sections['blog-featured-area'] = [
	[
		'id'       => 'show_featured_area',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Featured Area', 'publisher' ),
		'sub_desc' => esc_html__( 'Enable/Disable Featured Area from here.', 'publisher' ),
		'std'      => '1',
	],
	[
		'id'         => 'featured_heading',
		'type'       => 'text',
		'title'      => esc_html__( 'Heading', 'publisher' ),
		'sub_desc'   => esc_html__( 'Enter Heading from here.', 'publisher' ),
		'std'        => 'Featured',
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_subheading',
		'type'       => 'textarea',
		'title'      => esc_html__( 'Sub Heading', 'publisher' ),
		'sub_desc'   => esc_html__( 'Enter Sub Heading from here.', 'publisher' ),
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_tab_list',
		'type'       => 'group',
		'title'      => esc_html__( 'Categories Tab', 'publisher' ),
		'sub_desc'   => esc_html__( 'Customize the categories tab post from here.', 'publisher' ),
		'groupname'  => esc_html__( 'Tab', 'publisher' ), // Group name.
		'subfields'  => [
			[
				'id'    => 'tab_title',
				'type'  => 'text',
				'title' => esc_html__( 'Title', 'publisher' ),
			],
			[
				'id'       => 'category_tab_name',
				'type'     => 'select',
				'title'    => esc_html__( 'Category', 'publisher' ),
				'sub_desc' => esc_html__( 'Select a category or the latest posts for this section', 'publisher' ),
				'data'     => 'category',
				'args'     => [
					'include_latest' => __( 'Latest Posts', 'publisher' ),
					'hide_empty'     => 0,
				],
			],
			[
				'id'       => 'category_tab_color',
				'type'     => 'color',
				'title'    => esc_html__( 'Button Color', 'publisher' ),
				'sub_desc' => esc_html__( 'Tab button color.', 'publisher' ),
				'std'      => '#495c8e',
			],
			[
				'id'       => 'category_tab_bgcolor',
				'type'     => 'color',
				'title'    => esc_html__( 'Button Background Color', 'publisher' ),
				'sub_desc' => esc_html__( 'Tab button background color.', 'publisher' ),
				'std'      => '#ffffff',
			],
			[
				'id'       => 'category_tab_hover_color',
				'type'     => 'color',
				'title'    => esc_html__( 'Button Hover Color', 'publisher' ),
				'sub_desc' => esc_html__( 'Tab button hover color.', 'publisher' ),
				'std'      => '#495c8e',
			],
			[
				'id'       => 'category_tab_hover_bgcolor',
				'type'     => 'color',
				'title'    => esc_html__( 'Button Background Hover Color', 'publisher' ),
				'sub_desc' => esc_html__( 'Tab button background hover color.', 'publisher' ),
				'std'      => '#c9e8ee',
			],
			[
				'id'       => 'category_tab_border_radius',
				'type'     => 'text',
				'class'    => 'small-text',
				'title'    => esc_html__( 'Button Border Radius', 'publisher' ),
				'sub_desc' => esc_html__( 'Update button border radius in px.', 'publisher' ),
				'std'      => '17',
				'args'     => [ 'type' => 'number' ],
			],
		],
		'std'        => [
			'1' => [
				'group_title'                => '1',
				'group_sort'                 => '1',
				'tab_title'                  => __( 'Latest Posts', 'publisher' ),
				'category_tab_name'          => 'latest',
				'category_tab_color'         => '#495c8e',
				'category_tab_bgcolor'       => '#ffffff',
				'category_tab_hover_color'   => '#495c8e',
				'category_tab_hover_bgcolor' => '#c9e8ee',
				'category_tab_border_radius' => '17',
			],
		],
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_tab_postsnum',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Number of posts', 'publisher' ),
		'args'       => [ 'type' => 'number' ],
		'std'        => 4,
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_post_border_radius',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Post Border Radius', 'publisher' ),
		'sub_desc'   => esc_html__( 'Set Featured Post border radius from here.', 'publisher' ),
		'std'        => '10',
		'args'       => [ 'type' => 'number' ],
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_meta_info_heading',
		'type'       => 'heading',
		'title'      => esc_html__( 'Post Meta Info', 'publisher' ),
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'mts_featured_headline_meta_info',
		'type'       => 'multi_checkbox',
		'title'      => esc_html__( 'Post Meta Info', 'publisher' ),
		'sub_desc'   => esc_html__( 'Show or hide post meta info.', 'publisher' ),
		'options'    => [
			'category' => esc_html__( 'Category', 'publisher' ),
			'comment'  => esc_html__( 'Comments', 'publisher' ),
			'auth-img' => esc_html__( 'Author Image', 'publisher' ),
			'author'   => esc_html__( 'Author Name', 'publisher' ),
			'time'     => esc_html__( 'Time/Date', 'publisher' ),
			'likes'    => esc_html__( 'Likes', 'publisher' ),
		],
		'std'        => [
			'category',
			'auth-img',
			'author',
			'time',
			'likes',
		],
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'mts_featured_category_type',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Categories', 'publisher' ),
		'options'    => [
			'0' => esc_html__( 'First Category', 'publisher' ),
			'1' => esc_html__( 'ALL Categories', 'publisher' ),
		],
		'sub_desc'   => esc_html__( 'Show only first category or all the categories of post from here.', 'publisher' ),
		'std'        => '0',
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_post_excerpt',
		'type'       => 'switch',
		'title'      => esc_html__( 'Show Post Excerpts', 'publisher' ),
		'sub_desc'   => esc_html__( 'Use this button to show or hide small post excerpt.', 'publisher' ),
		'std'        => '1',
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_excerpt',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Excerpt Length', 'publisher' ),
		'sub_desc'   => esc_html__( 'Max lenght is 55 Words.', 'publisher' ),
		'args'       => [ 'type' => 'number' ],
		'std'        => '15',
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
			$featured_excerpt_dependency,
		],
	],
	[
		'id'         => 'custom_nav_heading',
		'type'       => 'heading',
		'title'      => esc_html__( 'Next/ Previous Navigation Button', 'publisher' ),
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'custom_nav_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Button Color', 'publisher' ),
		'sub_desc'   => esc_html__( 'Select slider button color.', 'publisher' ),
		'std'        => '#495c8e',
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'custom_nav_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Button Background Color', 'publisher' ),
		'sub_desc'   => esc_html__( 'Select slider button background color.', 'publisher' ),
		'std'        => '#ffffff',
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'custom_nav_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Button Hover Color', 'publisher' ),
		'sub_desc'   => esc_html__( 'Select slider button hover color.', 'publisher' ),
		'std'        => '#495c8e',
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'custom_nav_hover_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Button Background color', 'publisher' ),
		'sub_desc'   => esc_html__( 'Select slider button background hover color.', 'publisher' ),
		'args'       => [ 'opacity' => true ],
		'std'        => 'rgba(255,255,255,0.5)',
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_area_container_heading',
		'type'       => 'heading',
		'title'      => esc_html__( 'Featured Area Post Container', 'publisher' ),
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_area_background',
		'type'       => 'background',
		'title'      => esc_html__( 'Background', 'publisher' ),
		'sub_desc'   => esc_html__( 'Set Featured Area background color, pattern and image from here.', 'publisher' ),
		'options'    => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'        => [
			'color'         => '#ffffff',
			'use'           => 'upload',
			'image_pattern' => 'nobg',
			'image_upload'  => get_template_directory_uri() . '/images/featured-area.jpg',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_area_margin',
		'type'       => 'margin',
		'title'      => esc_html__( 'Margin', 'publisher' ),
		'sub_desc'   => esc_html__( 'Set Featured Area Margin from here.', 'publisher' ),
		'left'       => false,
		'right'      => false,
		'std'        => [
			'top'    => '0',
			'bottom' => publisher_px2rem( '64px' ),
		],
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_area_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Padding', 'publisher' ),
		'sub_desc'   => esc_html__( 'Set Featured Area Padding from here.', 'publisher' ),
		'std'        => [
			'top'    => publisher_px2rem( '55px' ),
			'right'  => '0',
			'bottom' => publisher_px2rem( '50px' ),
			'left'   => '0',
		],
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_area_border',
		'type'       => 'border',
		'title'      => esc_html__( 'Border', 'publisher' ),
		'sub_desc'   => esc_html__( 'Set Featured Area Border from here.', 'publisher' ),
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_area_post_heading',
		'type'       => 'heading',
		'title'      => esc_html__( 'Featured Area Typography', 'publisher' ),
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_heading_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Heading Font', 'publisher' ),
		'std'        => [
			'preview-text'  => 'Heading Font',
			'preview-color' => 'dark',
			'font-family'   => 'Red Hat Text',
			'font-weight'   => '700',
			'font-size'     => publisher_px2rem( '30px' ),
			'margin-bottom' => '5px',
			'color'         => '#ffffff',
			'css-selectors' => '.featured-area-section .heading',
		],
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_subheading_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Sub Heading Font', 'publisher' ),
		'std'        => [
			'preview-text'  => 'Sub Heading Font',
			'preview-color' => 'dark',
			'font-family'   => 'Lexend Deca',
			'font-weight'   => '400',
			'font-size'     => '14px',
			'line-height'   => '1.7',
			'margin-bottom' => '5px',
			'color'         => '#ffffff',
			'css-selectors' => '.featured-area-section .subheading',
		],
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_tab_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Tab Font', 'publisher' ),
		'color'      => false,
		'std'        => [
			'preview-text'   => 'Tab Font',
			'preview-color'  => 'dark',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '11px',
			'letter-spacing' => publisher_letter_spacing( 11, 182 ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '#tabs .tabs-menu .button',
		],
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_post_title_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Post Title Font', 'publisher' ),
		'std'        => [
			'preview-text'  => 'Post Title Font',
			'preview-color' => 'light',
			'font-family'   => 'Red Hat Text',
			'font-weight'   => '700',
			'font-size'     => '20px',
			'line-height'   => publisher_line_height( 20, 28 ),
			'margin-top'    => '5px',
			'margin-bottom' => '10px',
			'color'         => '#2d2b2b',
			'css-selectors' => '.featured-slider .latestPost .title a',
		],
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_post_excerpt_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Post Excerpt Font', 'publisher' ),
		'std'        => [
			'preview-text'   => 'Post Excerpt Font',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '12px',
			'line-height'    => publisher_line_height( 12, 20 ),
			'color'          => '#848fa1',
			'margin-bottom'  => publisher_px2rem( 25 ),
			'letter-spacing' => publisher_letter_spacing( 12, 36 ),
			'css-selectors'  => '.featured-slider .latestPost .front-view-content',
		],
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
			$featured_excerpt_dependency,
		],
	],
	[
		'id'         => 'featured_post_cats_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Category Typography', 'publisher' ),
		'std'        => [
			'preview-text'   => 'Category Font',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '12px',
			'color'          => '#bf2600',
			'letter-spacing' => publisher_letter_spacing( 12, 167 ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.featured-slider .thecategory a',
		],
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_post_author_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Author Meta Info Typography', 'publisher' ),
		'std'        => [
			'preview-text'   => 'Author Meta Info Font',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '14px',
			'color'          => '#495c8e',
			'line-height'    => '1.2',
			'letter-spacing' => publisher_letter_spacing( 14, 36 ),
			'css-selectors'  => '.featured-slider .theauthor, .featured-slider .thecomment, .featured-slider .sl-count',
		],
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'featured_post_date_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Date Typography', 'publisher' ),
		'std'        => [
			'preview-text'   => 'Date Font',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '11px',
			'color'          => '#848fa1',
			'line-height'    => '1.2',
			'letter-spacing' => publisher_letter_spacing( 11, 45 ),
			'css-selectors'  => '.featured-slider .thetime',
		],
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
	[
		'id'         => 'custom_nav_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Next/ Previous Button Typography', 'publisher' ),
		'color'      => false,
		'std'        => [
			'preview-text'   => 'Next/ Previous Button ',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '14px',
			'letter-spacing' => publisher_letter_spacing( 14, 36 ),
			'css-selectors'  => '.featured-slider .custom-nav a.button',
		],
		'dependency' => [
			'relation' => 'and',
			$featured_dependency,
		],
	],
];
