<?php
/**
 * HomePage Pagination
 *
 * @package Publisher
 */

$menus['blog-pagination'] = [
	'icon'  => 'fa-ellipsis-h',
	'title' => esc_html__( 'Pagination', 'publisher' ),
	'desc'  => esc_html__( 'From here, you can control the elements of pagination.', 'publisher' ),
];

// Dependency check - Default and Numbered pagination.
$default_pagination_dependency = [
	'relation' => 'and',
	[
		'field'      => 'mts_pagenavigation_type',
		'value'      => '2',
		'comparison' => '!=',
	],
	[
		'field'      => 'mts_pagenavigation_type',
		'value'      => '3',
		'comparison' => '!=',
	],
];

// Dependency check the load more button.
$loadmore_button_dependency = [
	'relation' => 'and',
	[
		'field'      => 'mts_pagenavigation_type',
		'value'      => '2',
		'comparison' => '==',
	],
];

$sections['blog-pagination'] = [

	[
		'id'       => 'mts_pagenavigation_type',
		'type'     => 'radio',
		'title'    => esc_html__( 'Pagination Type', 'publisher' ),
		'sub_desc' => esc_html__( 'Select pagination type.', 'publisher' ),
		'options'  => [
			'0' => esc_html__( 'Default (Next / Previous)', 'publisher' ),
			'1' => esc_html__( 'Numbered (1 2 3 4...)', 'publisher' ),
			'2' => esc_html__( 'AJAX (Load More Button)', 'publisher' ),
			'3' => esc_html__( 'AJAX (Auto Infinite Scroll)', 'publisher' ),
		],
		'std'      => '1',
	],

	[
		'id'         => 'pagenavigation_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Pagination Alignment', 'publisher' ),
		'sub_desc'   => esc_html__( 'Choose pagination alignment from here.', 'publisher' ),
		'options'    => [
			'left'   => esc_html__( 'Left', 'publisher' ),
			'center' => esc_html__( 'Center', 'publisher' ),
			'right'  => esc_html__( 'Right', 'publisher' ),
		],
		'std'        => 'center',
		'dependency' => $default_pagination_dependency,
	],

	[
		'id'         => 'load_more_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Load More Alignment', 'publisher' ),
		'sub_desc'   => esc_html__( 'Choose the load more alignment from here.', 'publisher' ),
		'options'    => [
			'left'   => esc_html__( 'Left', 'publisher' ),
			'center' => esc_html__( 'Center', 'publisher' ),
			'right'  => esc_html__( 'Right', 'publisher' ),
			'full'   => esc_html__( 'Full Width', 'publisher' ),
		],
		'std'        => 'center',
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'         => 'mts_pagenavigation_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination background color', 'publisher' ),
		'sub_desc'   => esc_html__( 'Select pagination background color.', 'publisher' ),
		'std'        => '#f4f4f4',
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More background color', 'publisher' ),
		'sub_desc'   => esc_html__( 'Select background color for load more button.', 'publisher' ),
		'std'        => '#f4f4f4',
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'         => 'mts_pagenavigation_hover_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination background hover color', 'publisher' ),
		'sub_desc'   => esc_html__( 'Select pagination background hover color.', 'publisher' ),
		'std'        => '#e4e7ee',
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_hover_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More background hover color', 'publisher' ),
		'sub_desc'   => esc_html__( 'Select background hover color for load more button.', 'publisher' ),
		'std'        => '#e4e7ee',
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'         => 'mts_pagenavigation_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination color', 'publisher' ),
		'sub_desc'   => esc_html__( 'Select pagination color.', 'publisher' ),
		'std'        => publisher_get_settings( 'primary_color_scheme' ),
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More color', 'publisher' ),
		'sub_desc'   => esc_html__( 'Select color for load more button.', 'publisher' ),
		'std'        => publisher_get_settings( 'primary_color_scheme' ),
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'         => 'mts_pagenavigation_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination hover color', 'publisher' ),
		'sub_desc'   => esc_html__( 'Select pagination hover color.', 'publisher' ),
		'std'        => publisher_get_settings( 'primary_color_scheme' ),
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More hover color', 'publisher' ),
		'sub_desc'   => esc_html__( 'Select hover color for load more button.', 'publisher' ),
		'std'        => publisher_get_settings( 'primary_color_scheme' ),
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'       => 'mts_pagenavigation_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Pagination Margin', 'publisher' ),
		'sub_desc' => esc_html__( 'Update pagination margin from here.', 'publisher' ),
		'std'      => [
			'top'    => '0',
			'right'  => '3px',
			'bottom' => '10px',
			'left'   => '3px',
		],
	],
	[
		'id'         => 'mts_pagenavigation_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Pagination Padding', 'publisher' ),
		'sub_desc'   => esc_html__( 'Update pagination padding from here.', 'publisher' ),
		'std'        => [
			'top'    => '18px',
			'right'  => '10px',
			'bottom' => '18px',
			'left'   => '10px',
		],
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Load More Padding', 'publisher' ),
		'sub_desc'   => esc_html__( 'Update padding for load more button from here.', 'publisher' ),
		'std'        => [
			'top'    => '18px',
			'right'  => '50px',
			'bottom' => '18px',
			'left'   => '50px',
		],
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'         => 'mts_pagenavigation_border_radius',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Pagination border radius', 'publisher' ),
		'sub_desc'   => esc_html__( 'Update pagination border radius in px.', 'publisher' ),
		'std'        => '50',
		'args'       => [ 'type' => 'number' ],
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_border_radius',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Load More border radius', 'publisher' ),
		'sub_desc'   => esc_html__( 'Update Load More border radius in px.', 'publisher' ),
		'std'        => '4',
		'args'       => [ 'type' => 'number' ],
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'         => 'pagenavigation_border',
		'type'       => 'border',
		'title'      => esc_html__( 'Border', 'publisher' ),
		'sub_desc'   => esc_html__( 'Select border', 'publisher' ),
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_border',
		'type'       => 'border',
		'title'      => esc_html__( 'Border', 'publisher' ),
		'sub_desc'   => esc_html__( 'Select border', 'publisher' ),
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'         => 'pagination_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Pagination Font', 'publisher' ),
		'color'      => false,
		'std'        => [
			'preview-text'   => 'Pagination Font',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '14px',
			'line-height'    => '1',
			'letter-spacing' => publisher_letter_spacing( 14, 36 ),
			'margin-top'     => '15px',
			'margin-bottom'  => '15px',
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.pagination',
		],
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'loadmore_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Load More Font', 'publisher' ),
		'color'      => false,
		'std'        => [
			'preview-text'   => 'Load More Font',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '14px',
			'letter-spacing' => publisher_letter_spacing( 14, 36 ),
			'margin-top'     => '15px',
			'margin-bottom'  => '15px',
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '#load-posts a',
		],
		'dependency' => $loadmore_button_dependency,
	],

];
