<?php
/**
 * HomePage Posts
 *
 * @package Publisher
 */

$features = publisher_get_settings( 'featured_categories' );
if ( empty( $features ) ) {
	return;
}
foreach ( $features as $feature ) :
	$title        = isset( $feature['mts_featured_title'] ) ? $feature['mts_featured_title'] : 'No Title';
	$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : '';
	if ( 'layout-default' === $posts_layout ) {
		$posts_layout = 'default';
	}
	$unique_id = isset( $feature['unique_id'] ) ? $feature['unique_id'] : '';

	$menus['blog']['child'][ 'blog-' . $unique_id ] = [
		'title' => $title,
		// translators: description.
		'desc'  => sprintf( wp_kses_post( __( 'From here, you can control the elements of %s', 'publisher' ) ), $title ),
	];

	// Dependency check that Title is enable.
	$post_title_dependency = [
		'field'      => 'featured_category_title_' . $unique_id,
		'value'      => '1',
		'comparison' => '==',
	];

	// Dependency check that excerpt is enable.
	$post_excerpt_dependency = [
		'relation' => 'and',
		[
			'field'      => 'post_excerpt_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		],
	];

	$post_hover_dependency = [
		'relation' => 'and',
		[
			'field'      => 'post_hover_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		],
	];

	$sections[ 'blog-' . $unique_id ] = [

		/**
		 * Layout Default Settings
		 *
		 * @package Publisher
		 */

		// Section Title.
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'publisher' ),
		] : null,

		( 'default' === $posts_layout ) ? [
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'publisher' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'publisher' ),
			'std'      => '0',
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'    => 'featured_category_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Section Title Typography', 'publisher' ),
			'std'   => [
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Lexend Deca',
				'font-weight'    => '700',
				'font-size'      => publisher_px2rem( '24px' ),
				'line-height'    => '1.2',
				'color'          => '#2d2b2b',
				'letter-spacing' => publisher_letter_spacing( 24, 16 ),
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'featured_category_title_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Post Title Margin', 'publisher' ),
			'sub_desc' => esc_html__( 'Set section title margin from here.', 'publisher' ),
			'std'      => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => publisher_px2rem( '30px' ),
				'left'   => '0',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'featured_category_title_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Post Title Padding', 'publisher' ),
			'sub_desc' => esc_html__( 'Set section title padding from here.', 'publisher' ),
			'std'      => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_title_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'publisher' ),
			'sub_desc' => esc_html__( 'Select border', 'publisher' ),
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		// Post Alignment.
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_content_alignment_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Alignment', 'publisher' ),
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_alignment_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Post Alignment', 'publisher' ),
			'sub_desc' => esc_html__( 'Choose the post alignment', 'publisher' ),
			'options'  => [
				'left'   => esc_html__( 'Left', 'publisher' ),
				'center' => esc_html__( 'Center', 'publisher' ),
				'right'  => esc_html__( 'Right', 'publisher' ),
			],
			'std'      => 'left',
		] : null,
		// Meta info.
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'publisher' ),
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'mts_home_headline_meta_info_' . $unique_id,
			'type'     => 'multi_checkbox',
			'title'    => esc_html__( 'Post Meta Info', 'publisher' ),
			'sub_desc' => esc_html__( 'Show or hide post meta info.', 'publisher' ),
			'options'  => [
				'category' => esc_html__( 'Category', 'publisher' ),
				'comment'  => esc_html__( 'Comments', 'publisher' ),
				'auth-img' => esc_html__( 'Author Image', 'publisher' ),
				'author'   => esc_html__( 'Author Name', 'publisher' ),
				'time'     => esc_html__( 'Time/Date', 'publisher' ),
				'likes'    => esc_html__( 'Likes', 'publisher' ),
			],
			'std'      => [
				'category',
				'auth-img',
				'author',
				'time',
				'likes',
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'mts_home_category_type_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Categories', 'publisher' ),
			'options'  => [
				'0' => esc_html__( 'First Category', 'publisher' ),
				'1' => esc_html__( 'ALL Categories', 'publisher' ),
			],
			'sub_desc' => esc_html__( 'Show only first category or all the categories of post from here.', 'publisher' ),
			'std'      => '0',
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'    => 'mts_cats_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Category Typography', 'publisher' ),
			'std'   => [
				'preview-text'   => 'Category Font',
				'preview-color'  => 'light',
				'font-family'    => 'Lexend Deca',
				'font-weight'    => '400',
				'font-size'      => '12px',
				'color'          => '#bf2600',
				'letter-spacing' => publisher_letter_spacing( 12, 167 ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .thecategory a',
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'    => 'mts_author_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Author Meta Info Typography', 'publisher' ),
			'std'   => [
				'preview-text'   => 'Author Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Lexend Deca',
				'font-weight'    => '400',
				'font-size'      => '14px',
				'color'          => '#495c8e',
				'line-height'    => '1.2',
				'letter-spacing' => publisher_letter_spacing( 14, 36 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .theauthor, .layout-' . $unique_id . ' .latestPost .thecomment, .layout-' . $unique_id . ' .latestPost .sl-count, .layout-' . $unique_id . ' .latestPost .sl-count',
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'    => 'mts_date_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Date Typography', 'publisher' ),
			'std'   => [
				'preview-text'   => 'Date Font',
				'preview-color'  => 'light',
				'font-family'    => 'Lexend Deca',
				'font-weight'    => '400',
				'font-size'      => '11px',
				'color'          => '#848fa1',
				'line-height'    => '1.2',
				'letter-spacing' => publisher_letter_spacing( 11, 45 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .thetime',
			],
		] : null,
		// Post Container.
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'publisher' ),
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'publisher' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'publisher' ),
			'options'  => [
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => [],       // false to disable, array of options to override default ( optional ).
				'attachment'    => [],       // false to disable, array of options to override default ( optional ).
				'position'      => [],       // false to disable, array of options to override default ( optional ).
				'size'          => [],       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => [],       // false to disable, array of options to override default ( optional ).
			],
			'std'      => [
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => [
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				],
				'parallax'      => '0',
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'publisher' ),
			'sub_desc' => esc_html__( 'Select border', 'publisher' ),
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'publisher' ),
			'sub_desc' => esc_html__( 'Post margin.', 'publisher' ),
			'left'     => false,
			'right'    => false,
			'std'      => [
				'top'    => publisher_px2rem( '56px' ),
				'bottom' => '0',
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'publisher' ),
			'sub_desc' => esc_html__( 'Post padding.', 'publisher' ),
			'std'      => [
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'publisher' ),
			'std'   => [
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Lexend Deca',
				'font-weight'   => '700',
				'font-size'     => '16px',
				'line-height'   => '1.5',
				'margin-top'    => '5px',
				'margin-bottom' => '5px',
				'color'         => '#2d2b2b',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_excerpt_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show Post Excerpts', 'publisher' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide post excerpt.', 'publisher' ),
			'std'      => '1',
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'post_excerpt_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Post Excerpt Font', 'publisher' ),
			'std'        => [
				'preview-text'   => 'Post Excerpt Font',
				'preview-color'  => 'light',
				'font-family'    => 'Lexend Deca',
				'font-weight'    => '400',
				'font-size'      => '12px',
				'line-height'    => publisher_line_height( 12, 20 ),
				'color'          => '#848fa1',
				'margin-bottom'  => publisher_px2rem( 15 ),
				'letter-spacing' => publisher_letter_spacing( 12, 36 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			],
			'dependency' => $post_excerpt_dependency,
		] : null,

		/**
		 * Layout 1 Settings
		 *
		 * @package Publisher
		 */

		// Section Title.
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'publisher' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'publisher' ),
			'std'      => '0',
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'featured_category_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Section Title Typography', 'publisher' ),
			'std'   => [
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Lexend Deca',
				'font-weight'    => '700',
				'font-size'      => publisher_px2rem( '24px' ),
				'line-height'    => '1.2',
				'color'          => '#2d2b2b',
				'letter-spacing' => publisher_letter_spacing( 24, 16 ),
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'featured_category_title_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Post Title Margin', 'publisher' ),
			'sub_desc' => esc_html__( 'Set section title margin from here.', 'publisher' ),
			'std'      => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => publisher_px2rem( '30px' ),
				'left'   => '0',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'featured_category_title_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Post Title Padding', 'publisher' ),
			'sub_desc' => esc_html__( 'Set section title padding from here.', 'publisher' ),
			'std'      => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_title_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'publisher' ),
			'sub_desc' => esc_html__( 'Select border', 'publisher' ),
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		// Post Alignment.
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'post_content_alignment_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Alignment', 'publisher' ),
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_alignment_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Post Alignment', 'publisher' ),
			'sub_desc' => esc_html__( 'Choose the post alignment', 'publisher' ),
			'options'  => [
				'left'   => esc_html__( 'Left', 'publisher' ),
				'center' => esc_html__( 'Center', 'publisher' ),
				'right'  => esc_html__( 'Right', 'publisher' ),
			],
			'std'      => 'left',
		] : null,
		// Meta info.
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'publisher' ),
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'mts_home_headline_meta_info_' . $unique_id,
			'type'     => 'multi_checkbox',
			'title'    => esc_html__( 'Post Meta Info', 'publisher' ),
			'sub_desc' => esc_html__( 'Show or hide post meta info.', 'publisher' ),
			'options'  => [
				'category' => esc_html__( 'Category', 'publisher' ),
				'comment'  => esc_html__( 'Comments', 'publisher' ),
				'auth-img' => esc_html__( 'Author Image', 'publisher' ),
				'author'   => esc_html__( 'Author Name', 'publisher' ),
				'time'     => esc_html__( 'Time/Date', 'publisher' ),
				'likes'    => esc_html__( 'Likes', 'publisher' ),
			],
			'std'      => [
				'category',
				'auth-img',
				'author',
				'time',
				'likes',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'mts_home_category_type_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Categories', 'publisher' ),
			'options'  => [
				'0' => esc_html__( 'First Category', 'publisher' ),
				'1' => esc_html__( 'ALL Categories', 'publisher' ),
			],
			'sub_desc' => esc_html__( 'Show only first category or all the categories of post from here.', 'publisher' ),
			'std'      => '0',
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'mts_cats_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Category Typography', 'publisher' ),
			'std'   => [
				'preview-text'   => 'Category Font',
				'preview-color'  => 'light',
				'font-family'    => 'Lexend Deca',
				'font-weight'    => '400',
				'font-size'      => '12px',
				'color'          => '#bf2600',
				'letter-spacing' => publisher_letter_spacing( 12, 167 ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .thecategory a',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'mts_author_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Author Meta Info Typography', 'publisher' ),
			'std'   => [
				'preview-text'   => 'Author Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Lexend Deca',
				'font-weight'    => '400',
				'font-size'      => '14px',
				'color'          => '#495c8e',
				'line-height'    => '1.2',
				'letter-spacing' => publisher_letter_spacing( 14, 36 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .theauthor, .layout-' . $unique_id . ' .latestPost .thecomment, .layout-' . $unique_id . ' .latestPost .sl-count, .layout-' . $unique_id . ' .latestPost .sl-count',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'mts_date_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Date Typography', 'publisher' ),
			'std'   => [
				'preview-text'   => 'Date Font',
				'preview-color'  => 'light',
				'font-family'    => 'Lexend Deca',
				'font-weight'    => '400',
				'font-size'      => '11px',
				'color'          => '#848fa1',
				'line-height'    => '1.2',
				'letter-spacing' => publisher_letter_spacing( 11, 45 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .thetime',
			],
		] : null,
		// Post Container.
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'publisher' ),
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'publisher' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'publisher' ),
			'options'  => [
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => [],       // false to disable, array of options to override default ( optional ).
				'attachment'    => [],       // false to disable, array of options to override default ( optional ).
				'position'      => [],       // false to disable, array of options to override default ( optional ).
				'size'          => [],       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => [],       // false to disable, array of options to override default ( optional ).
			],
			'std'      => [
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => [
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				],
				'parallax'      => '0',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'publisher' ),
			'sub_desc' => esc_html__( 'Select border', 'publisher' ),
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'publisher' ),
			'sub_desc' => esc_html__( 'Post margin.', 'publisher' ),
			'left'     => false,
			'right'    => false,
			'std'      => [
				'top'    => publisher_px2rem( '56px' ),
				'bottom' => '0',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'publisher' ),
			'sub_desc' => esc_html__( 'Post padding.', 'publisher' ),
			'std'      => [
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'publisher' ),
			'std'   => [
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Red Hat Text',
				'font-weight'   => '700',
				'font-size'     => '20px',
				'line-height'   => publisher_line_height( 20, 28 ),
				'margin-top'    => '5px',
				'margin-bottom' => '10px',
				'color'         => '#2d2b2b',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_excerpt_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show Post Excerpts', 'publisher' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide post excerpt.', 'publisher' ),
			'std'      => '1',
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'         => 'post_excerpt_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Post Excerpt Font', 'publisher' ),
			'std'        => [
				'preview-text'   => 'Post Excerpt Font',
				'preview-color'  => 'light',
				'font-family'    => 'Lexend Deca',
				'font-weight'    => '400',
				'font-size'      => '12px',
				'line-height'    => publisher_line_height( 12, 20 ),
				'color'          => '#848fa1',
				'margin-bottom'  => publisher_px2rem( 25 ),
				'letter-spacing' => publisher_letter_spacing( 12, 36 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			],
			'dependency' => $post_excerpt_dependency,
		] : null,

		/**
		 * Layout 2 Settings
		 *
		 * @package Publisher
		 */

		// Section Title.
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'publisher' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'publisher' ),
			'std'      => '0',
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'featured_category_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Section Title Typography', 'publisher' ),
			'std'   => [
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Lexend Deca',
				'font-weight'    => '700',
				'font-size'      => publisher_px2rem( '24px' ),
				'line-height'    => '1.2',
				'color'          => '#2d2b2b',
				'letter-spacing' => publisher_letter_spacing( 24, 16 ),
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'featured_category_title_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Post Title Margin', 'publisher' ),
			'sub_desc' => esc_html__( 'Set section title margin from here.', 'publisher' ),
			'std'      => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => publisher_px2rem( '30px' ),
				'left'   => '0',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'featured_category_title_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Post Title Padding', 'publisher' ),
			'sub_desc' => esc_html__( 'Set section title padding from here.', 'publisher' ),
			'std'      => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_title_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'publisher' ),
			'sub_desc' => esc_html__( 'Select border', 'publisher' ),
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		// Post Alignment.
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'post_content_alignment_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Alignment', 'publisher' ),
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_alignment_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Post Alignment', 'publisher' ),
			'sub_desc' => esc_html__( 'Choose the post alignment', 'publisher' ),
			'options'  => [
				'left'   => esc_html__( 'Left', 'publisher' ),
				'center' => esc_html__( 'Center', 'publisher' ),
				'right'  => esc_html__( 'Right', 'publisher' ),
			],
			'std'      => 'left',
		] : null,
		// Meta info.
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'publisher' ),
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'mts_home_headline_meta_info_' . $unique_id,
			'type'     => 'multi_checkbox',
			'title'    => esc_html__( 'Post Meta Info', 'publisher' ),
			'sub_desc' => esc_html__( 'Show or hide post meta info.', 'publisher' ),
			'options'  => [
				'category' => esc_html__( 'Category', 'publisher' ),
				'comment'  => esc_html__( 'Comments', 'publisher' ),
				'auth-img' => esc_html__( 'Author Image', 'publisher' ),
				'author'   => esc_html__( 'Author Name', 'publisher' ),
				'time'     => esc_html__( 'Time/Date', 'publisher' ),
				'likes'    => esc_html__( 'Likes', 'publisher' ),
			],
			'std'      => [
				'category',
				'auth-img',
				'author',
				'time',
				'likes',
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'mts_home_category_type_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Categories', 'publisher' ),
			'options'  => [
				'0' => esc_html__( 'First Category', 'publisher' ),
				'1' => esc_html__( 'ALL Categories', 'publisher' ),
			],
			'sub_desc' => esc_html__( 'Show only first category or all the categories of post from here.', 'publisher' ),
			'std'      => '0',
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'mts_cats_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Category Typography', 'publisher' ),
			'std'   => [
				'preview-text'   => 'Category Font',
				'preview-color'  => 'light',
				'font-family'    => 'Lexend Deca',
				'font-weight'    => '400',
				'font-size'      => '12px',
				'color'          => '#bf2600',
				'letter-spacing' => publisher_letter_spacing( 12, 167 ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .thecategory a',
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'mts_author_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Author Meta Info Typography', 'publisher' ),
			'std'   => [
				'preview-text'   => 'Author Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Lexend Deca',
				'font-weight'    => '400',
				'font-size'      => '14px',
				'color'          => '#495c8e',
				'line-height'    => '1.2',
				'letter-spacing' => publisher_letter_spacing( 14, 36 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .theauthor, .layout-' . $unique_id . ' .latestPost .thecomment, .layout-' . $unique_id . ' .latestPost .sl-count',
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'mts_date_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Date Typography', 'publisher' ),
			'std'   => [
				'preview-text'   => 'Date Font',
				'preview-color'  => 'light',
				'font-family'    => 'Lexend Deca',
				'font-weight'    => '400',
				'font-size'      => '11px',
				'color'          => '#848fa1',
				'line-height'    => '1.2',
				'letter-spacing' => publisher_letter_spacing( 11, 45 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .thetime',
			],
		] : null,
		// Post Container.
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'publisher' ),
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'publisher' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'publisher' ),
			'options'  => [
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => [],       // false to disable, array of options to override default ( optional ).
				'attachment'    => [],       // false to disable, array of options to override default ( optional ).
				'position'      => [],       // false to disable, array of options to override default ( optional ).
				'size'          => [],       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => [],       // false to disable, array of options to override default ( optional ).
			],
			'std'      => [
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => [
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				],
				'parallax'      => '0',
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'publisher' ),
			'sub_desc' => esc_html__( 'Select border', 'publisher' ),
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'publisher' ),
			'sub_desc' => esc_html__( 'Post margin.', 'publisher' ),
			'left'     => false,
			'right'    => false,
			'std'      => [
				'top'    => publisher_px2rem( '56px' ),
				'bottom' => '0',
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'publisher' ),
			'sub_desc' => esc_html__( 'Post padding.', 'publisher' ),
			'std'      => [
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'publisher' ),
			'std'   => [
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Red Hat Text',
				'font-weight'   => '700',
				'font-size'     => '24px',
				'line-height'   => publisher_line_height( 20, 28 ),
				'margin-top'    => '5px',
				'margin-bottom' => '10px',
				'color'         => '#2d2b2b',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_excerpt_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show Post Excerpts', 'publisher' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide post excerpt.', 'publisher' ),
			'std'      => '1',
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'         => 'post_excerpt_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Post Excerpt Font', 'publisher' ),
			'std'        => [
				'preview-text'   => 'Post Excerpt Font',
				'preview-color'  => 'light',
				'font-family'    => 'Lexend Deca',
				'font-weight'    => '400',
				'font-size'      => '14px',
				'line-height'    => publisher_line_height( 12, 20 ),
				'color'          => '#848fa1',
				'margin-bottom'  => publisher_px2rem( 25 ),
				'letter-spacing' => publisher_letter_spacing( 12, 36 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			],
			'dependency' => $post_excerpt_dependency,
		] : null,

		/**
		 * Layout HTML Settings
		 *
		 * @package Publisher
		 */
		( 'layout-html' === $posts_layout ) ? [
			'id'       => 'post_layout_html_' . $unique_id,
			'type'     => 'ace_editor',
			'mode'     => 'html',
			'title'    => esc_html__( 'HTML Post', 'publisher' ),
			'sub_desc' => esc_html__( 'Paste your HTML, Text or other code here.', 'publisher' ),
			'std'      => '<img src="' . get_template_directory_uri() . '/images/banner.jpg">',
		] : null,
		( 'layout-html' === $posts_layout ) ? [
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'publisher' ),
			'sub_desc' => esc_html__( 'Post margin.', 'publisher' ),
			'left'     => false,
			'right'    => false,
			'std'      => [
				'top'    => publisher_px2rem( '56px' ),
				'bottom' => '0',
			],
		] : null,
		( 'layout-html' === $posts_layout ) ? [
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'publisher' ),
			'sub_desc' => esc_html__( 'Post padding.', 'publisher' ),
			'std'      => [
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			],
		] : null,

	];
endforeach;
