<?php
/**
 * Single AuthorBox
 *
 * @package Publisher
 */

$menus['single-authorbox'] = [
	'icon'  => 'fa-pencil',
	'title' => esc_html__( 'Author Box', 'publisher' ),
	'desc'  => esc_html__( 'From here, you can control the appearance and functionality of Author box in single posts page.', 'publisher' ),
];

$authorbox_social_share = [
	'relation' => 'and',
	[
		'field'      => 'authorbox_social_share',
		'value'      => '1',
		'comparison' => '==',
	],
];

$sections['single-authorbox'] = [

	[
		'id'    => 'authorbox_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Author box Settings', 'publisher' ),
	],
	[
		'id'       => 'authorbox_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Background', 'publisher' ),
		'sub_desc' => esc_html__( 'Set Author box background color, pattern and image for subscribe box from here.', 'publisher' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '#f4f4f4',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],
	[
		'id'       => 'author_box_title',
		'type'     => 'text',
		'title'    => esc_html__( 'Author Box Title', 'publisher' ),
		'sub_desc' => esc_html__( 'Enter author box title.', 'publisher' ),
		'std'      => '',
	],
	[
		'id'       => 'authorbox_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Margin', 'publisher' ),
		'sub_desc' => esc_html__( 'Set Author box margin from here.', 'publisher' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => publisher_px2rem( '65px' ),
			'left'   => '0',
		],
	],
	[
		'id'       => 'authorbox_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Padding', 'publisher' ),
		'sub_desc' => esc_html__( 'Set Author box padding from here.', 'publisher' ),
		'std'      => [
			'top'    => publisher_px2rem( '30px' ),
			'right'  => publisher_px2rem( '30px' ),
			'bottom' => publisher_px2rem( '30px' ),
			'left'   => publisher_px2rem( '30px' ),
		],
	],
	[
		'id'       => 'authorbox_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'publisher' ),
		'sub_desc' => esc_html__( 'Select border', 'publisher' ),
	],
	[
		'id'       => 'authorbox_border_radius',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Border Radius', 'publisher' ),
		'sub_desc' => esc_html__( 'Author box border radius.', 'publisher' ),
		'std'      => '10',
		'args'     => [ 'type' => 'number' ],
	],
	[
		'id'    => 'authorbox_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Author Box Title Font', 'publisher' ),
		'std'   => [
			'preview-text'  => 'Author Box Title Font',
			'preview-color' => 'light',
			'font-family'   => 'Red Hat Text',
			'font-weight'   => '700',
			'font-size'     => '20px',
			'line-height'   => '1.2',
			'color'         => '#2d2b2b',
			'margin-bottom' => publisher_px2rem( '25px' ),
			'css-selectors' => '.postauthor h4',
		],
	],
	[
		'id'    => 'authorbox_author_name_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Author Box Name Font', 'publisher' ),
		'std'   => [
			'preview-text'   => 'Author Box Name Font',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '14px',
			'line-height'    => '1.2',
			'color'          => '#495c8e',
			'margin-bottom'  => '4px',
			'letter-spacing' => publisher_letter_spacing( 14, 36 ),
			'additional-css' => 'text-transform: capitalize;',
			'css-selectors'  => '.postauthor h5, .postauthor h5 a',
		],
	],
	[
		'id'    => 'authorbox_registered_date_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Author Registered Date Font', 'publisher' ),
		'std'   => [
			'preview-text'   => 'Author Registered Date Font',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '11px',
			'line-height'    => '1.2',
			'color'          => '#818b9e',
			'letter-spacing' => publisher_letter_spacing( 11, 45 ),
			'css-selectors'  => '.postauthor .registered-date',
		],
	],
	[
		'id'    => 'authorbox_text_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Author Box Text Font', 'publisher' ),
		'std'   => [
			'preview-text'  => 'Author Box Text Font',
			'preview-color' => 'light',
			'font-family'   => 'Lexend Deca',
			'font-weight'   => '400',
			'font-size'     => '14px',
			'line-height'   => publisher_line_height( 14, 23 ),
			'color'         => '#505f79',
			'margin-top'    => publisher_px2rem( '5px' ),
			'css-selectors' => '.postauthor p',
		],
	],
	[
		'id'    => 'author_img_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Author Image Settings', 'publisher' ),
	],
	[
		'id'       => 'author_box_image',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Author Image', 'publisher' ),
		'sub_desc' => esc_html__( 'Use this button to show/hide author image.', 'publisher' ),
		'std'      => '1',
	],
	[
		'id'       => 'single_author_image_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Margin', 'publisher' ),
		'sub_desc' => esc_html__( 'Set Author image margin from here.', 'publisher' ),
		'std'      => [
			'top'    => '',
			'right'  => publisher_px2rem( '15px' ),
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'single_author_image_border_radius',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Border Radius', 'publisher' ),
		'sub_desc' => esc_html__( 'Author image border radius.', 'publisher' ),
		'std'      => '40',
		'args'     => [ 'type' => 'number' ],
	],
	[
		'id'    => 'single_authorbox_social_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Author box Social Settings', 'publisher' ),
	],
	[
		'id'       => 'authorbox_social_share',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Author Social Share', 'publisher' ),
		'sub_desc' => esc_html__( 'Enable/Disable author social share in the authorbox.', 'publisher' ),
		'std'      => '1',
	],
	[
		'id'         => 'author_social_margin',
		'type'       => 'margin',
		'title'      => esc_html__( 'Margin', 'publisher' ),
		'sub_desc'   => esc_html__( 'Set author social share margin from here.', 'publisher' ),
		'std'        => [
			'top'    => '0',
			'right'  => publisher_px2rem( '20px' ),
			'bottom' => '10px',
			'left'   => '0',
		],
		'dependency' => $authorbox_social_share,
	],
	[
		'id'         => 'author_social_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Padding', 'publisher' ),
		'sub_desc'   => esc_html__( 'Set author social share padding from here.', 'publisher' ),
		'std'        => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
		'dependency' => $authorbox_social_share,
	],
	[
		'id'         => 'author_social_background',
		'type'       => 'color',
		'title'      => esc_html__( 'Social Background Color', 'publisher' ),
		'sub_desc'   => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'publisher' ),
		'dependency' => $authorbox_social_share,
	],
	[
		'id'         => 'author_social_hover_background',
		'type'       => 'color',
		'title'      => esc_html__( 'Social Background Hover Color', 'publisher' ),
		'sub_desc'   => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'publisher' ),
		'dependency' => $authorbox_social_share,
	],
	[
		'id'         => 'author_social_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Social Color', 'publisher' ),
		'sub_desc'   => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'publisher' ),
		'std'        => '#000000',
		'dependency' => $authorbox_social_share,
	],
	[
		'id'         => 'author_social_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Social Hover Color', 'publisher' ),
		'sub_desc'   => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'publisher' ),
		'std'        => publisher_get_settings( 'primary_color_scheme' ),
		'dependency' => $authorbox_social_share,
	],
	[
		'id'         => 'author_social_border_radius',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Social border radius', 'publisher' ),
		'std'        => '0',
		'args'       => [ 'type' => 'number' ],
		'dependency' => $authorbox_social_share,
	],
];
