<?php
/**
 * Single Related Posts
 *
 * @package Publisher
 */

$menus['single-related'] = [
	'icon'  => 'fa-sitemap',
	'title' => esc_html__( 'Related Posts', 'publisher' ),
	'desc'  => esc_html__( 'From here, you can control the appearance and functionality of related posts in single posts page.', 'publisher' ),
];

$sections['single-related'] = [

	[
		'id'       => 'related_post_title',
		'type'     => 'text',
		'title'    => esc_html__( 'Related Posts Title', 'publisher' ),
		'sub_desc' => esc_html__( 'Enter the title text to show in the related posts section.', 'publisher' ),
		'std'      => 'Similar Post',
	],

	[
		'id'       => 'related_posts_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Background', 'publisher' ),
		'sub_desc' => esc_html__( 'Set Related Posts background color, pattern and image from here.', 'publisher' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],

	[
		'id'       => 'related_posts_layouts',
		'type'     => 'radio_img',
		'title'    => esc_html__( 'Related Posts Layouts', 'publisher' ),
		'sub_desc' => esc_html__( 'Choose the Related Posts layouts for your site.', 'publisher' ),
		'options'  => [
			'default'  => [ 'img' => $uri . 'related/r1.jpg' ],
			'related2' => [ 'img' => $uri . 'related/r2.jpg' ],
			'related3' => [ 'img' => $uri . 'related/r3.jpg' ],
			'related5' => [ 'img' => $uri . 'related/r5.jpg' ],
			'related6' => [ 'img' => $uri . 'related/r6.jpg' ],
		],
		'std'      => 'default',
	],

	[
		'id'       => 'mts_related_postsnum',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Number of related posts', 'publisher' ),
		'sub_desc' => esc_html__( 'Enter the number of posts to show in the related posts section.', 'publisher' ),
		'std'      => '2',
		'args'     => [
			'type' => 'number',
		],
	],

	[
		'id'         => 'related_excerpt',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Excerpt Length', 'publisher' ),
		'sub_desc'   => esc_html__( 'Max lenght is 55 Words.', 'publisher' ),
		'args'       => [ 'type' => 'number' ],
		'std'        => '18',
		'dependency' => [
			'relation' => 'or',
			[
				'field'      => 'related_posts_layouts',
				'value'      => 'related2',
				'comparison' => '==',
			],
			[
				'field'      => 'related_posts_layouts',
				'value'      => 'related5',
				'comparison' => '==',
			],
		],
	],

	[
		'id'         => 'related_posts_adcode',
		'type'       => 'ace_editor',
		'mode'       => 'html',
		'title'      => esc_html__( 'Related Posts Ad', 'publisher' ),
		'sub_desc'   => esc_html__( 'Paste your Adsense, BSA or other ad code here to show ads in Related Posts Area.', 'publisher' ),
		'dependency' => [
			'relation' => 'or',
			[
				'field'      => 'related_posts_layouts',
				'value'      => 'related5',
				'comparison' => '==',
			],
			[
				'field'      => 'related_posts_layouts',
				'value'      => 'related6',
				'comparison' => '==',
			],
		],
	],

	[
		'id'       => 'related_posts_position',
		'type'     => 'button_set',
		'title'    => esc_html__( 'Related Posts Position', 'publisher' ),
		'sub_desc' => esc_html__( 'Choose the position for related posts, below content will be Full width', 'publisher' ),
		'options'  => [
			'default' => esc_html__( 'Default', 'publisher' ),
			'full'    => esc_html__( 'Below Content', 'publisher' ),
		],
		'std'      => 'default',
	],
	[
		'id'       => 'mts_related_headline_meta_info',
		'type'     => 'multi_checkbox',
		'title'    => esc_html__( 'Post Meta Info', 'publisher' ),
		'sub_desc' => esc_html__( 'Show or hide post meta info.', 'publisher' ),
		'options'  => [
			'category' => esc_html__( 'Category', 'publisher' ),
			'comment'  => esc_html__( 'Comments', 'publisher' ),
			'auth-img' => esc_html__( 'Author Image', 'publisher' ),
			'author'   => esc_html__( 'Author Name', 'publisher' ),
			'time'     => esc_html__( 'Time/Date', 'publisher' ),
			'likes'    => esc_html__( 'Likes', 'publisher' ),
		],
		'std'      => [
			'category',
			'auth-img',
			'author',
			'time',
			'likes',
		],
	],
	[
		'id'       => 'mts_related_category_type',
		'type'     => 'button_set',
		'title'    => esc_html__( 'Categories', 'publisher' ),
		'options'  => [
			'0' => esc_html__( 'First Category', 'publisher' ),
			'1' => esc_html__( 'ALL Categories', 'publisher' ),
		],
		'sub_desc' => esc_html__( 'Show only first category or all the categories of post from here.', 'publisher' ),
		'std'      => '0',
	],
	[
		'id'       => 'related_posts_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Margin', 'publisher' ),
		'sub_desc' => esc_html__( 'Set related posts margin from here.', 'publisher' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => publisher_px2rem( '35px' ),
			'left'   => '0',
		],
	],
	[
		'id'       => 'related_posts_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Padding', 'publisher' ),
		'sub_desc' => esc_html__( 'Set related posts padding from here.', 'publisher' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],

	[
		'id'       => 'related_posts_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'publisher' ),
		'sub_desc' => esc_html__( 'Select border', 'publisher' ),
	],

	[
		'id'    => 'related_posts_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Related Posts Title', 'publisher' ),
		'std'   => [
			'preview-text'  => 'Related Posts Title',
			'preview-color' => 'light',
			'font-family'   => 'Lexend Deca',
			'font-weight'   => '700',
			'font-size'     => '16px',
			'line-height'   => '1.5',
			'margin-top'    => '5px',
			'margin-bottom' => '5px',
			'color'         => '#2d2b2b',
			'css-selectors' => '.related-posts .latestPost .title a',
		],
	],
	[
		'id'    => 'related_meta_cats_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Category Typography', 'publisher' ),
		'std'   => [
			'preview-text'   => 'Category Font',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '12px',
			'color'          => '#bf2600',
			'letter-spacing' => publisher_letter_spacing( 12, 167 ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.related-posts .latestPost .thecategory a',
		],
	],
	[
		'id'    => 'related_meta_author_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Author Meta Info Typography', 'publisher' ),
		'std'   => [
			'preview-text'   => 'Author Meta Info Font',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '14px',
			'color'          => '#495c8e',
			'line-height'    => '1.2',
			'letter-spacing' => publisher_letter_spacing( 14, 36 ),
			'css-selectors'  => '.related-posts .latestPost .theauthor, .related-posts .latestPost .thecomment, .related-posts .latestPost .sl-count',
		],
	],
	[
		'id'    => 'related_meta_date_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Date Typography', 'publisher' ),
		'std'   => [
			'preview-text'   => 'Date Font',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '11px',
			'color'          => '#848fa1',
			'line-height'    => '1.2',
			'letter-spacing' => publisher_letter_spacing( 11, 45 ),
			'css-selectors'  => '.related-posts .latestPost .thetime',
		],
	],
	[
		'id'         => 'related_posts_text_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Related Posts Text', 'publisher' ),
		'std'        => [
			'preview-text'   => 'Related Posts Text',
			'preview-color'  => 'light',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '12px',
			'line-height'    => publisher_line_height( 12, 20 ),
			'color'          => '#848fa1',
			'margin-bottom'  => publisher_px2rem( 15 ),
			'letter-spacing' => publisher_letter_spacing( 12, 36 ),
			'css-selectors'  => '.related-posts .latestPost .front-view-content',
		],
		'dependency' => [
			'relation' => 'or',
			[
				'field'      => 'related_posts_layouts',
				'value'      => 'related1',
				'comparison' => '==',
			],
			[
				'field'      => 'related_posts_layouts',
				'value'      => 'related2',
				'comparison' => '==',
			],
			[
				'field'      => 'related_posts_layouts',
				'value'      => 'related5',
				'comparison' => '==',
			],
		],
	],
	[
		'id'    => 'related_posts_article_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Related Posts Articles', 'publisher' ),
	],
	[
		'id'       => 'related_article_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Articles Background', 'publisher' ),
		'sub_desc' => esc_html__( 'Set Related Posts Articles background color, pattern and image from here.', 'publisher' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '#f4f4f4',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],

	[
		'id'       => 'related_article_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Articles Padding', 'publisher' ),
		'sub_desc' => esc_html__( 'Set related posts articles padding from here.', 'publisher' ),
		'std'      => [
			'top'    => publisher_px2rem( '22px' ),
			'right'  => publisher_px2rem( '22px' ),
			'bottom' => publisher_px2rem( '22px' ),
			'left'   => publisher_px2rem( '22px' ),
		],
	],

];
