<?php
/**
 * Single Styling
 *
 * @package Publisher
 */

$menus['single-styling'] = [
	'icon'  => 'fa-paint-brush',
	'title' => esc_html__( 'Single Styling', 'publisher' ),
	'desc'  => esc_html__( 'From here, you can control the appearance and functionality of your single posts page.', 'publisher' ),
];

$sections['single-styling'] = [
	[
		'id'    => 'mts_single_styling_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Single Styling', 'publisher' ),
	],
	[
		'id'       => 'single_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Background', 'publisher' ),
		'sub_desc' => esc_html__( 'Set background color, pattern and image of Single, Page, Archive, Search, Category and 404 Page from here.', 'publisher' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],

	[
		'id'       => 'mts_single_styling_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Single Margin', 'publisher' ),
		'sub_desc' => esc_html__( 'Set single post margin from here.', 'publisher' ),
		'left'     => false,
		'right'    => false,
		'std'      => [
			'top'    => '0',
			'bottom' => publisher_px2rem( '32px' ),
		],
	],
	[
		'id'       => 'mts_single_styling_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Single Padding', 'publisher' ),
		'sub_desc' => esc_html__( 'Set single post padding from here.', 'publisher' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'single_styling_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'publisher' ),
		'sub_desc' => esc_html__( 'Select border', 'publisher' ),
	],
	[
		'id'    => 'single_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Single Post Title', 'publisher' ),
		'std'   => [
			'preview-text'   => 'Single Post Title',
			'preview-color'  => 'dark',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '700',
			'font-size'      => publisher_px2rem( '36px' ),
			'line-height'    => publisher_line_height( 36, 48 ),
			'margin-top'     => '8px',
			'margin-bottom'  => publisher_px2rem( '30px' ),
			'color'          => '#ffffff',
			'letter-spacing' => publisher_letter_spacing( 36, 14 ),
			'css-selectors'  => '.single-title',
		],
	],
	[
		'id'    => 'single_meta_cats_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Category Typography', 'publisher' ),
		'std'   => [
			'preview-text'   => 'Category Font',
			'preview-color'  => 'dark',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '12px',
			'color'          => '#ffffff',
			'letter-spacing' => publisher_letter_spacing( 12, 167 ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.single_post .thecategory a, .single-full-header .thecategory a',
		],
	],
	[
		'id'    => 'single_meta_author_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Author Meta Info Typography', 'publisher' ),
		'std'   => [
			'preview-text'   => 'Author Meta Info Font',
			'preview-color'  => 'dark',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '14px',
			'color'          => '#ffffff',
			'line-height'    => '1.2',
			'letter-spacing' => publisher_letter_spacing( 14, 36 ),
			'css-selectors'  => '.single_post .theauthor, .single-full-header .theauthor, .single_post .thecomment, .single-full-header .thecomment, .single_post .like-text, .single-full-header .like-text, .single_post .sl-count, .single-full-header .sl-count',
		],
	],
	[
		'id'    => 'single_meta_date_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Date Typography', 'publisher' ),
		'std'   => [
			'preview-text'   => 'Date Font',
			'preview-color'  => 'dark',
			'font-family'    => 'Lexend Deca',
			'font-weight'    => '400',
			'font-size'      => '11px',
			'color'          => '#c8cdd9',
			'line-height'    => '1.2',
			'letter-spacing' => publisher_letter_spacing( 11, 45 ),
			'css-selectors'  => '.single_post .thetime, .single-full-header .thetime',
		],
	],
	[
		'id'    => 'single_title_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Single Titles Styling', 'publisher' ),
	],
	[
		'id'       => 'single_title_alignment',
		'type'     => 'button_set',
		'title'    => esc_html__( 'Single Page Title Alignment', 'publisher' ),
		'sub_desc' => esc_html__( 'Choose the single page title alignment', 'publisher' ),
		'options'  => [
			'left'   => esc_html__( 'Left', 'publisher' ),
			'center' => esc_html__( 'Center', 'publisher' ),
			'right'  => esc_html__( 'Right', 'publisher' ),
		],
		'std'      => 'left',
	],
	[
		'id'       => 'single_title_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Single Page Title Background Color', 'publisher' ),
		'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'publisher' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],
	[
		'id'       => 'single_title_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Single Page Title Padding', 'publisher' ),
		'sub_desc' => esc_html__( 'Set single page title padding from here.', 'publisher' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'single_title_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'publisher' ),
		'sub_desc' => esc_html__( 'Select border', 'publisher' ),
	],
	[
		'id'       => 'single_page_titles_font',
		'type'     => 'typography',
		'title'    => esc_html__( 'Single Sections Title', 'publisher' ),
		'sub_desc' => esc_html__( 'Manage Title typography of Related Posts, Comments and Reply from here.', 'publisher' ),
		'std'      => [
			'preview-text'  => 'Title Font',
			'preview-color' => 'light',
			'font-family'   => 'Lexend Deca',
			'font-weight'   => '700',
			'font-size'     => '20px',
			'line-height'   => '1.2',
			'color'         => '#2d2b2b',
			'margin-bottom' => publisher_px2rem( '22px' ),
			'css-selectors' => '.related-posts h4, #respond h3, #respond h4, .total-comments',
		],
	],
];
