<?php
/**
 * Single Tab
 *
 * @package Publisher
 */

$menus['single-general'] = [
	'title' => esc_html__( 'General', 'publisher' ),
	'desc'  => esc_html__( 'From here, you can control the appearance and functionality of your single posts page.', 'publisher' ),
];

// Dependency check - Featured Image Size.
$featured_image_size = [
	'relation' => 'and',
	[
		'field'      => 'featured_image_size',
		'value'      => 'full',
		'comparison' => '==',
	],
];

$sections['single-general'] = [

	[
		'id'       => 'show_single_featured',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Featured image', 'publisher' ),
		'sub_desc' => esc_html__( 'Enable/Disable the Featured images in the single post.', 'publisher' ),
		'std'      => '1',
	],
	[
		'id'       => 'featured_image_size',
		'type'     => 'button_set',
		'title'    => esc_html__( 'Header Size', 'publisher' ),
		'sub_desc' => esc_html__( 'Choose the featured image size', 'publisher' ),
		'options'  => [
			'default' => esc_html__( 'Content Size', 'publisher' ),
			'full'    => esc_html__( 'Full Width', 'publisher' ),
		],
		'std'      => 'full',
	],
	[
		'id'         => 'featured_image_margin',
		'type'       => 'margin',
		'title'      => esc_html__( 'Header Image Margin', 'publisher' ),
		'sub_desc'   => esc_html__( 'Set header image margin from here.', 'publisher' ),
		'std'        => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => publisher_px2rem( '96px' ),
			'left'   => '0',
		],
		'dependency' => $featured_image_size,
	],
	[
		'id'         => 'featured_image_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Header Image Padding', 'publisher' ),
		'sub_desc'   => esc_html__( 'Set header image padding from here.', 'publisher' ),
		'std'        => [
			'top'    => publisher_px2rem( '45px' ),
			'right'  => '0',
			'bottom' => publisher_px2rem( '30px' ),
			'left'   => '0',
		],
		'dependency' => $featured_image_size,
	],
	[
		'id'         => 'featured_image_opacity',
		'type'       => 'color',
		'title'      => esc_html__( 'Header Image Overlay', 'publisher' ),
		'args'       => [ 'opacity' => true ],
		'std'        => 'rgba(73, 92, 142, 0.8)',
		'dependency' => $featured_image_size,
	],
	[
		'id'         => 'featured_text_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Alignment', 'publisher' ),
		'sub_desc'   => esc_html__( 'Choose the featured image text alignment', 'publisher' ),
		'options'    => [
			'left'   => esc_html__( 'Left', 'publisher' ),
			'center' => esc_html__( 'Center', 'publisher' ),
			'right'  => esc_html__( 'Right', 'publisher' ),
		],
		'std'        => 'center',
		'dependency' => $featured_image_size,
	],
	[
		'id'         => 'single_meta_info_top_border',
		'type'       => 'border',
		'title'      => esc_html__( 'Border', 'publisher' ),
		'sub_desc'   => esc_html__( 'Meta Info Top Border', 'publisher' ),
		'std'        => [
			'direction' => 'top',
			'size'      => '1',
			'style'     => 'solid',
			'color'     => '#7f8aa4',
		],
		'dependency' => $featured_image_size,
	],
	[
		'id'         => 'show_prev_next',
		'type'       => 'switch',
		'title'      => esc_html__( 'Show preview and next article buttons', 'publisher' ),
		'sub_desc'   => esc_html__( 'Use this button to show or hide preview and next article buttons.', 'publisher' ),
		'std'        => '0',
		'dependency' => $featured_image_size,
	],

	[
		'id'       => 'mts_single_post_layout',
		'type'     => 'layout2',
		'title'    => esc_html__( 'Single Post Layout', 'publisher' ),
		'sub_desc' => esc_html__( 'Customize the look of single posts', 'publisher' ),
		'options'  => [
			'enabled'  => [
				'content' => [
					'label'     => esc_html__( 'Post Content', 'publisher' ),
					'subfields' => [],
				],
				'tags'    => [
					'label'     => esc_html__( 'Tags', 'publisher' ),
					'subfields' => [],
				],
				'author'  => [
					'label'     => esc_html__( 'Author Box', 'publisher' ),
					'subfields' => [],
				],
				'related' => [
					'label'     => esc_html__( 'Related Posts', 'publisher' ),
					'subfields' => [
						[
							'id'       => 'mts_related_posts_taxonomy',
							'type'     => 'switch',
							'title'    => esc_html__( 'Related Posts Taxonomy', 'publisher' ),
							'options'  => [
								'tags'       => esc_html__( 'Tags', 'publisher' ),
								'categories' => esc_html__( 'Categories', 'publisher' ),
							],
							'class'    => 'green',
							'sub_desc' => esc_html__( 'Related Posts based on tags or categories.', 'publisher' ),
							'std'      => 'categories',
						],
					],
				],
			],
			'disabled' => [
				'subscribe' => [
					'label'     => esc_html__( 'Subscribe Box', 'publisher' ),
					'subfields' => [],
				],
			],
		],
	],
	[
		'id'       => 'mts_single_headline_meta_info',
		'type'     => 'multi_checkbox',
		'title'    => esc_html__( 'Post Meta Info', 'publisher' ),
		'sub_desc' => esc_html__( 'Show or hide post meta info.', 'publisher' ),
		'options'  => [
			'category' => esc_html__( 'Category', 'publisher' ),
			'comment'  => esc_html__( 'Comments', 'publisher' ),
			'auth-img' => esc_html__( 'Author Image', 'publisher' ),
			'author'   => esc_html__( 'Author Name', 'publisher' ),
			'time'     => esc_html__( 'Time/Date', 'publisher' ),
			'likes'    => esc_html__( 'Likes', 'publisher' ),
		],
		'std'      => [
			'category',
			'auth-img',
			'author',
			'time',
			'likes',
		],
	],
	[
		'id'       => 'mts_single_category_type',
		'type'     => 'button_set',
		'title'    => esc_html__( 'Categories', 'publisher' ),
		'options'  => [
			'0' => esc_html__( 'First Category', 'publisher' ),
			'1' => esc_html__( 'ALL Categories', 'publisher' ),
		],
		'sub_desc' => esc_html__( 'Show only first category or all the categories of post from here.', 'publisher' ),
		'std'      => '0',
	],
	[
		'id'       => 'mts_single_like_title',
		'type'     => 'text',
		'title'    => esc_html__( 'Like Button Title', 'publisher' ),
		'sub_desc' => esc_html__( 'Enter Like button title text from here.', 'publisher' ),
		'std'      => 'Like This Article',
	],
	[
		'id'       => 'mts_author_comment',
		'type'     => 'switch',
		'title'    => esc_html__( 'Highlight Author Comment', 'publisher' ),
		'sub_desc' => esc_html__( 'Use this button to highlight author comments.', 'publisher' ),
		'std'      => '1',
	],

];
