<?php
/*-----------------------------------------------------------------------------------

	Plugin Name: MyThemeShop Popular Posts
	Version: 2.0.2

-----------------------------------------------------------------------------------*/
if ( ! class_exists( 'mts_popular_posts_widget' ) ) {
	class mts_popular_posts_widget extends WP_Widget {

		public function __construct() {
			parent::__construct(
				'mts_popular_posts_widget',
				sprintf( __( '%sTrending Posts', 'publisher' ), MTS_THEME_WHITE_LABEL ? '' : 'MTS ' ),
				array( 'description' => __( 'Displays most Trending Posts with Thumbnail.', 'publisher' ) )
			);
			add_action( 'admin_enqueue_scripts', array( $this, 'widget_scripts' ) );
			add_action( 'admin_footer-widgets.php', [ $this, 'print_scripts' ], 9999 );
			add_action( 'admin_footer-widgets.php', [ $this, 'publisher_custom_stylings' ], 9999 );
		}

		/**
		 * Enqueue Widget Scripts
		 *
		 * @param $hook
		 */
		function widget_scripts( $hook ) {
			if ( 'widgets.php' !== $hook ) {
				return;
			}	
			wp_enqueue_script( 'switch-layout', trailingslashit( get_template_directory_uri() ) . '/includes/widgets/js/switch-layout.js', false );

			wp_enqueue_style( 'wp-color-picker' );
			wp_enqueue_script( 'wp-color-picker' );
		}

		/**
		 * Print scripts.
		 *
		 * @since 1.0
		 */
		public function print_scripts() {
			?>
			<script>
				( function( $ ){
					function initColorPicker( widget ) {
						widget.find( '.color-picker' ).wpColorPicker( {
							change: _.throttle( function() { // For Customizer
								$(this).trigger( 'change' );
							}, 3000 )
						});
					}

					function onFormUpdate( event, widget ) {
						initColorPicker( widget );
					}

					$( document ).on( 'widget-added widget-updated', onFormUpdate );

					$( document ).ready( function() {
						$( '#widgets-right .widget:has(.color-picker)' ).each( function () {
							initColorPicker( $( this ) );
						} );
					} );
				}( jQuery ) );
			</script>
			<?php
		}

		public function publisher_custom_stylings() {
			?>
			<style>
				.widget .wp-picker-active {
					position: relative;
					z-index: 2;
				}
				.wp-picker-container .wp-color-result.button { margin-right: 0 }
				.styling-options {
					clear: both;
					position: relative;
				}
				.widget .wp-picker-container {	
					position: relative;
   		 			margin-top: 7px;	
				}
				.wp-picker-holder { z-index: 0 }
			</style>

			<?php
		}

		public function form( $instance ) {
			$defaults       = [
				'title_length'   => 10,
				'category'       => 0,
				'author_name'    => 1,
				'author_img'     => 0,
				'date'           => 1,
				'days'           => 30,
				'likes'          => 1,
				'show_thumb3'    => 0,
				'box_layout'     => 'horizontal-small',
				'border_radius'  => 12,
				'show_excerpt'   => 1,
				'excerpt_length' => 16,
				'trend_bg_color' => '#e9f6f8',
				'title_color'    => '#2d2b2b',
				'text_color'     => '#7e8c9f',
				'link_color'     => '#495c8e',
				'pd_top'         => 25,
				'pd_right'       => 24,
				'pd_bottom'      => 25,
				'pd_left'        => 24,
			];
			$instance       = wp_parse_args( (array) $instance, $defaults );
			$title          = isset( $instance['title'] ) ? $instance['title'] : __( 'Trending', 'publisher' );
			$title_length   = isset( $instance['title_length'] ) ? intval( $instance['title_length'] ) : 7;
			$qty            = isset( $instance['qty'] ) ? intval( $instance['qty'] ) : 3;
			$category       = isset( $instance['category'] ) ? intval( $instance['category'] ) : 0;
			$author_name    = isset( $instance['author_name'] ) ? intval( $instance['author_name'] ) : 1;
			$author_img     = isset( $instance['author_img'] ) ? esc_attr( $instance['author_img'] ) : 0;
			$date           = isset( $instance['date'] ) ? intval( $instance['date'] ) : 1;
			$days           = isset( $instance['days'] ) ? intval( $instance['days'] ) : 30;
			$likes          = isset( $instance['likes'] ) ? esc_attr( $instance['likes'] ) : 1;
			$show_thumb3    = isset( $instance['show_thumb3'] ) ? intval( $instance['show_thumb3'] ) : 0;
			$box_layout     = $instance['box_layout'];
			$border_radius  = isset( $instance['border_radius'] ) ? intval( $instance['border_radius'] ) : 0;
			$show_excerpt   = isset( $instance['show_excerpt'] ) ? esc_attr( $instance['show_excerpt'] ) : 1;
			$excerpt_length = isset( $instance['excerpt_length'] ) ? intval( $instance['excerpt_length'] ) : 10;
			?>
			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title:', 'publisher' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'days' ); ?>"><?php esc_html_e( 'Popular limit (days):', 'publisher' ); ?>
					<input id="<?php echo $this->get_field_id( 'days' ); ?>" name="<?php echo $this->get_field_name( 'days' ); ?>" type="number" class="small-text" min="1" step="1" value="<?php echo esc_attr( $days ); ?>" />
				</label>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'qty' ); ?>"><?php esc_html_e( 'Number of Posts to show', 'publisher' ); ?></label>
				<input id="<?php echo $this->get_field_id( 'qty' ); ?>" name="<?php echo $this->get_field_name( 'qty' ); ?>" type="number" class="small-text" min="1" step="1" value="<?php echo esc_attr( $qty ); ?>" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'title_length' ); ?>"><?php esc_html_e( 'Title Length:', 'publisher' ); ?>
				<input id="<?php echo $this->get_field_id( 'title_length' ); ?>" name="<?php echo $this->get_field_name( 'title_length' ); ?>" type="number" class="small-text" min="1" step="1" value="<?php echo esc_attr( $title_length ); ?>" />
				</label>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'show_thumb3' ); ?>">
					<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id( 'show_thumb3' ); ?>" name="<?php echo $this->get_field_name( 'show_thumb3' ); ?>" value="1" <?php if ( isset( $instance['show_thumb3'] ) ) { checked( 1, $instance['show_thumb3'], true ); } ?> />
					<?php esc_html_e( 'Show Thumbnails', 'publisher' ); ?>
				</label>
			</p>

			<p class="post-box-layout">
				<label for="<?php echo $this->get_field_id( 'box_layout' ); ?>"><?php esc_html_e( 'Posts layout:', 'publisher' ); ?></label>
				<select id="<?php echo $this->get_field_id( 'box_layout' ); ?>" name="<?php echo $this->get_field_name( 'box_layout' ); ?>">
					<option value="horizontal-small" <?php selected( $box_layout, 'horizontal-small', true ); ?>><?php esc_html_e( 'Horizontal', 'publisher' ); ?></option>
					<option value="vertical-small" <?php selected( $box_layout, 'vertical-small', true ); ?>><?php esc_html_e( 'Vertical', 'publisher' ); ?></option>
				</select>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'category' ); ?>">
					<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id( 'category' ); ?>" name="<?php echo $this->get_field_name( 'category' ); ?>" value="1" <?php checked( 1, $instance['category'], true ); ?> />
					<?php esc_html_e( 'Show posts categories', 'publisher' ); ?>
				</label>
			</p>

			<p>
				<label for="<?php echo esc_html( $this->get_field_id( 'likes' ) ); ?>">
					<input type="checkbox" class="checkbox" id="<?php echo esc_html( $this->get_field_id( 'likes' ) ); ?>" name="<?php echo $this->get_field_name( 'likes' ); ?>" value="1" <?php checked( 1, $instance['likes'], true ); ?> />
					<?php esc_html_e( 'Show post likes', 'publisher' ); ?>
				</label>
			</p>

			<p>
				<label for="<?php echo esc_html( $this->get_field_id( 'author_img' ) ); ?>">
					<input type="checkbox" class="checkbox" id="<?php echo esc_html( $this->get_field_id( 'author_img' ) ); ?>" name="<?php echo $this->get_field_name( 'author_img' ); ?>" value="1" <?php checked( 1, $instance['author_img'], true ); ?> />
					<?php esc_html_e( 'Show Author Image', 'publisher' ); ?>
				</label>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'author_name' ); ?>">
					<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id( 'author_name' ); ?>" name="<?php echo $this->get_field_name( 'author_name' ); ?>" value="1" <?php checked( 1, $instance['author_name'], true ); ?> />
					<?php esc_html_e( 'Show author name with link', 'publisher' ); ?>
				</label>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'date' ); ?>">
					<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id( 'date' ); ?>" name="<?php echo $this->get_field_name( 'date' ); ?>" value="1" <?php checked( 1, $instance['date'], true ); ?> />
					<?php esc_html_e( 'Show post date', 'publisher' ); ?>
				</label>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'show_excerpt' ); ?>">
					<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id( 'show_excerpt' ); ?>" name="<?php echo $this->get_field_name( 'show_excerpt' ); ?>" value="1" <?php checked( 1, $instance['show_excerpt'], true ); ?> />
					<?php esc_html_e( 'Show excerpt', 'publisher' ); ?>
				</label>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'excerpt_length' ); ?>"><?php esc_html_e( 'Excerpt Length:', 'publisher' ); ?>
					<input id="<?php echo $this->get_field_id( 'excerpt_length' ); ?>" name="<?php echo $this->get_field_name( 'excerpt_length' ); ?>" type="number" class="small-text" min="1" step="1" value="<?php echo esc_attr( $excerpt_length ); ?>" />
				</label>
			</p>

			<p style="font-size: 14px; margin-bottom: 0;border-bottom: 1px dashed; padding-bottom: 10px;"><strong><?php esc_html_e( 'Fonts Color', 'publisher' ); ?></strong></p>

			<!-- Title Color -->
			<p>
				<label for="<?php echo $this->get_field_id( 'title_color' ); ?>"><?php esc_html_e( 'Title Color', 'publisher' ); ?></label><br>
				<input type="text" name="<?php echo $this->get_field_name( 'title_color' ); ?>" class="color-picker" id="<?php echo $this->get_field_id( 'title_color' ); ?>" value="<?php echo $instance['title_color']; ?>" data-default-color="#2d2b2b" />
			</p>

			<!-- Text Color -->
			<p>
				<label for="<?php echo $this->get_field_id( 'text_color' ); ?>"><?php esc_html_e( 'Text Color', 'publisher' ); ?></label><br>
				<input type="text" name="<?php echo $this->get_field_name( 'text_color' ); ?>" class="color-picker" id="<?php echo $this->get_field_id( 'text_color' ); ?>" value="<?php echo $instance['text_color']; ?>" data-default-color="#7e8c9f" />
			</p>

			<!-- Link Color -->
			<p>
				<label for="<?php echo $this->get_field_id( 'link_color' ); ?>"><?php esc_html_e( 'Link Color', 'publisher' ); ?></label><br>
				<input type="text" name="<?php echo $this->get_field_name( 'link_color' ); ?>" class="color-picker" id="<?php echo $this->get_field_id( 'link_color' ); ?>" value="<?php echo $instance['link_color']; ?>" data-default-color="#495c8e" />
			</p>

			<p style="font-size: 14px; margin-bottom: 0;border-bottom: 1px dashed; padding-bottom: 10px;"><strong><?php esc_html_e( 'Post Container', 'publisher' ); ?></strong></p>

			<p>
				<label for="<?php echo $this->get_field_id( 'trend_bg_color' ); ?>"><?php esc_html_e( 'Background', 'publisher' ); ?></label><br>
				<input type="text" name="<?php echo $this->get_field_name( 'trend_bg_color' ); ?>" class="color-picker" id="<?php echo $this->get_field_id( 'trend_bg_color' ); ?>" value="<?php echo $instance['trend_bg_color']; ?>" data-default-color="#e9f6f8" />
			</p>

			<p>
				<p style="font-size: 14px; margin-bottom: 0;"><strong><?php esc_html_e( 'Padding', 'publisher' ); ?></strong></p>
				<p style="float: left; width: 22%; margin-right: 4%;">
					<label for="<?php echo $this->get_field_id( 'pd_top' ); ?>"><?php esc_html_e( 'Top', 'publisher' ); ?></label>
					<input id="<?php echo $this->get_field_id( 'pd_top' ); ?>" name="<?php echo $this->get_field_name( 'pd_top' ); ?>" type="number" value="<?php echo esc_attr( $instance['pd_top'] ); ?>" style="width: 100%" />
				</p>

				<!-- Padding Right-->
				<p style="float: left; width: 22%; margin-right: 4%;">
					<label for="<?php echo $this->get_field_id( 'pd_right' ); ?>"><?php esc_html_e( 'Right', 'publisher' ); ?></label>
					<input id="<?php echo $this->get_field_id( 'pd_right' ); ?>" name="<?php echo $this->get_field_name( 'pd_right' ); ?>" type="number" value="<?php echo esc_attr( $instance['pd_right'] ); ?>" style="width: 100%" />
				</p>

				<!-- Padding Bottom-->
				<p style="float: left; width: 22%; margin-right: 4%;">
					<label for="<?php echo $this->get_field_id( 'pd_bottom' ); ?>"><?php esc_html_e( 'Bottom', 'publisher' ); ?></label>
					<input id="<?php echo $this->get_field_id( 'pd_bottom' ); ?>" name="<?php echo $this->get_field_name( 'pd_bottom' ); ?>" type="number" value="<?php echo esc_attr( $instance['pd_bottom'] ); ?>" style="width: 100%" />
				</p>

				<!-- Padding Left-->
				<p style="float: left; width: 22%;">
					<label for="<?php echo $this->get_field_id( 'pd_left' ); ?>"><?php esc_html_e( 'Left', 'publisher' ); ?></label>
					<input id="<?php echo $this->get_field_id( 'pd_left' ); ?>" name="<?php echo $this->get_field_name( 'pd_left' ); ?>" type="number" value="<?php echo esc_attr( $instance['pd_left'] ); ?>" style="width: 100%" />
				</p>
			</p>

			<p class="post-border-radius">
				<label for="<?php echo $this->get_field_id( 'border_radius' ); ?>"><?php esc_html_e( 'Border Radius: ', 'publisher' ); ?></label>
				<input id="<?php echo $this->get_field_id( 'border_radius' ); ?>" name="<?php echo $this->get_field_name( 'border_radius' ); ?>" type="number" class="small-text" step="1" value="<?php echo esc_attr( $border_radius ); ?>" />
			</p>

			<?php
		}

		public function update( $new_instance, $old_instance ) {
			$instance                   = [];
			$instance['title']          = strip_tags( $new_instance['title'] );
			$instance['qty']            = intval( $new_instance['qty'] );
			$instance['title_length']   = intval( $new_instance['title_length'] );
			$instance['category']       = intval( $new_instance['category'] );
			$instance['author_name']    = intval( $new_instance['author_name'] );
			$instance['author_img']     = intval( $new_instance['author_img'] );
			$instance['date']           = intval( $new_instance['date'] );
			$instance['days']           = intval( $new_instance['days'] );
			$instance['likes']          = intval( $new_instance['likes'] );
			$instance['show_thumb3']    = intval( $new_instance['show_thumb3'] );
			$instance['box_layout']     = $new_instance['box_layout'];
			$instance['border_radius']  = intval( $new_instance['border_radius'] );
			$instance['show_excerpt']   = intval( $new_instance['show_excerpt'] );
			$instance['excerpt_length'] = intval( $new_instance['excerpt_length'] );
			$instance['trend_bg_color'] = sanitize_hex_color( $new_instance['trend_bg_color'] );
			$instance['title_color']    = sanitize_hex_color( $new_instance['title_color'] );
			$instance['text_color']     = sanitize_hex_color( $new_instance['text_color'] );
			$instance['link_color']     = sanitize_hex_color( $new_instance['link_color'] );
			$instance['pd_top']         = intval( $new_instance['pd_top'] );
			$instance['pd_right']       = intval( $new_instance['pd_right'] );
			$instance['pd_bottom']      = intval( $new_instance['pd_bottom'] );
			$instance['pd_left']        = intval( $new_instance['pd_left'] );
			return $instance;
		}

		public function widget( $args, $instance ) {
			extract( $args );
			$title          = apply_filters( 'widget_title', $instance['title'] );
			$title_length   = $instance['title_length'];
			$category       = $instance['category'];
			$author_name    = $instance['author_name'];
			$author_img     = isset( $instance['author_img'] ) ? $instance['author_img'] : '';
			$date           = $instance['date'];
			$days           = $instance['days'];
			$likes          = isset( $instance['likes'] ) ? $instance['likes'] : '';
			$qty            = (int) $instance['qty'];
			$show_thumb3    = (int) $instance['show_thumb3'];
			$box_layout     = isset( $instance['box_layout'] ) ? $instance['box_layout'] : 'horizontal-small';
			$border_radius  = esc_attr( $instance['border_radius'] ) . 'px';
			$show_excerpt   = $instance['show_excerpt'];
			$excerpt_length = $instance['excerpt_length'];
			$trend_bg_color = isset( $instance['trend_bg_color'] ) ? sanitize_hex_color( $instance['trend_bg_color'] ) : '';
			$title_color    = isset( $instance['title_color'] ) ? sanitize_hex_color( $instance['title_color'] ) : '';
			$text_color     = isset( $instance['text_color'] ) ? sanitize_hex_color( $instance['text_color'] ) : '';
			$link_color     = isset( $instance['link_color'] ) ? sanitize_hex_color( $instance['link_color'] ) : '';
			$pd_top         = isset( $instance['pd_top'] ) ? esc_attr( $instance['pd_top'] ) . 'px' : '';
			$pd_right       = isset( $instance['pd_right'] ) ? esc_attr( $instance['pd_right'] ) . 'px' : '';
			$pd_bottom      = isset( $instance['pd_bottom'] ) ? esc_attr( $instance['pd_bottom'] ) . 'px' : '';
			$pd_left        = isset( $instance['pd_left'] ) ? esc_attr( $instance['pd_left'] ) . 'px' : '';

			$before_widget = preg_replace( '/class="([^"]+)"/i', 'class="$1 ' . ( isset( $instance['box_layout'] ) ? $instance['box_layout'] : 'horizontal-small' ) . '"', $before_widget ); // Add horizontal/vertical class to widget
			echo $before_widget;
			if ( ! empty( $title ) ) echo $before_title . $title . $after_title;
			echo self::get_popular_posts( $qty, $title_length, $category, $author_name, $author_img, $date, $days, $likes, $show_thumb3, $box_layout, $border_radius, $show_excerpt, $excerpt_length );
			echo $after_widget;
			?>

			<style>
			<?php
				echo '#' . $this->id . '.widget_mts_popular_posts_widget { 
					border-radius:' . esc_attr( $border_radius ) . ';
					background:' . sanitize_hex_color( $trend_bg_color ) . ';
					padding-top:' . esc_attr( $pd_top ) . ';
					padding-right:' . esc_attr( $pd_right ) . ';
					padding-bottom:' . esc_attr( $pd_bottom ) . ';
					padding-left:' . esc_attr( $pd_left ) . ';
				} ';
				echo '#' . $this->id . '.widget_mts_popular_posts_widget h3 { 
					color:' . sanitize_hex_color( $title_color ) . '!important;
				} ';
				echo '#' . $this->id . ' .popular-posts .post-title a { 
					color:' . sanitize_hex_color( $title_color ) . ';
				} ';
				echo '#' . $this->id . ' .popular-posts .post-excerpt { 
					color:' . sanitize_hex_color( $text_color ) . ';
				} ';
				echo '#' . $this->id . ' .popular-posts .thecategory a { 
					color:' . sanitize_hex_color( $text_color ) . ';
				} ';
				echo '#' . $this->id . ' .popular-posts .theauthor { 
					color:' . sanitize_hex_color( $link_color ) . ';
				} ';
				echo '#' . $this->id . ' .popular-posts .sl-count { 
					color:' . sanitize_hex_color( $link_color ) . ';
				} ';
				echo '#' . $this->id . ' li.no-thumb:after { 
					color:' . sanitize_hex_color( $link_color ) . '!important;
				} ';
			?>
			</style>
			<?php
		}

		public function get_popular_posts( $qty, $title_length, $category, $author_name, $author_img, $date, $days, $likes, $show_thumb3, $box_layout, $border_radius, $show_excerpt, $excerpt_length ) {

			$no_image = ( $show_thumb3 ) ? ' have-thumb' : ' no-thumb';

			if ( 'horizontal-small' === $box_layout ) {
				$thumbnail     = 'widgetthumb';
				$open_li_item  = '<li class="post-box horizontal-small horizontal-container' . $no_image . '"><div class="horizontal-container-inner">';
				$close_li_item = '</div></li>';
			} else {
				$thumbnail     = 'widgetfull';
				$open_li_item  = '<li class="post-box vertical-small' . $no_image . '">';
				$close_li_item = '</li>';
			}

			$popular_days = [];
			if ( $days ) {
				$popular_days = [
					// set date ranges.
					'after'     => "$days day ago",
					'before'    => 'today',
					// allow exact matches to be returned.
					'inclusive' => true,
				];
			}

			global $post;

			$popular = get_posts(
				[
					'suppress_filters'    => false,
					'ignore_sticky_posts' => 1,
					'orderby'             => 'comment_count',
					'numberposts'         => $qty,
					'date_query'          => $popular_days,
				]
			);

			echo '<ul class="popular-posts">';
			foreach ( $popular as $post ) :
				setup_postdata( $post );
			?>
				<?php echo $open_li_item; ?>
					<?php if ( $show_thumb3 ) : ?>
					<div class="post-img">
						<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>">
							<?php if ( has_post_thumbnail() ) { ?>
								<?php the_post_thumbnail( 'publisher-' . $thumbnail, array( 'title' => '' ) ); ?>
							<?php } else { ?>
								<img class="wp-post-image" src="<?php echo get_template_directory_uri() . '/images/nothumb-publisher-' . $thumbnail . '.png'; ?>" alt="<?php the_title_attribute(); ?>"/>
							<?php } ?>
						</a>
					</div>
					<?php endif; ?>
					<div class="post-data">
						<div class="post-data-container">
							<?php
							if ( $category ) :
								printf( '<div class="thecategory">%s</div>', publisher_get_the_category(' ') );
							endif;
							?>
							<div class="post-title">
								<?php
								if ( $likes ) :
									echo '<div class="widgetlikebutton">';
									echo get_simple_likes_button( get_the_ID() );
									echo '</div>';
								endif;
								?>
								<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>"><?php echo esc_html( publisher_truncate( get_the_title(), $title_length, 'words' ) ); ?></a>
							</div>
							<?php if ( $show_excerpt ) : ?>
							<div class="post-excerpt">
								<?php
								if ( empty( publisher_excerpt() ) ) {
									echo publisher_truncate( get_the_content(), '16', 'words' );
								} else {
									echo publisher_excerpt( $excerpt_length );
								}
								?>
							</div>
								<?php
							endif;
							if ( $author_img || $author_name || $date || $likes ) :
								?>
								<div class="post-info-bottom">
									<?php
									if ( $author_img || $author_name || $date ) :
										if ( $author_img ) :
											?>
											<div class="theauthorimage"><?php echo get_avatar( get_the_author_meta( 'email' ), 40 ); ?></div>
											<?php
										endif;
										echo '<div class="theauthortime">';
										if ( $author_name ) :
											$tag = esc_html__( 'Written by', 'publisher' );
											printf( '<div class="theauthor"><span>%1$s</span> <span>%2$s</span></div>', $tag, get_the_author_posts_link() );
										endif;
										if ( $date ) :
											printf( '<div class="thetime date updated"><span>%s</span></div>', get_the_time( get_option( 'date_format' ) ) );
										endif;
										echo '</div>';
									endif;
									?>
								</div>
								<?php
							endif;
							?>
						</div>
					</div>
				<?php echo $close_li_item; ?>
			<?php
			endforeach;
			wp_reset_postdata();
			echo '</ul>' . "\r\n";
			?>

		<?php
		}

	}
}
// Register widget
add_action( 'widgets_init', 'register_mts_popular_posts_widget' );
function register_mts_popular_posts_widget() {
	register_widget( 'mts_popular_posts_widget' );
}